=======================
``psyclone.tests.nemo``
=======================

.. automodule:: psyclone.tests.nemo

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.tests.nemo.nemo_config_test
   psyclone.tests.nemo.nemo_psy_test

.. currentmodule:: psyclone.tests.nemo
